summaryrefslogtreecommitdiff
path: root/FL/Fl_Widget.H
diff options
context:
space:
mode:
authorManolo Gouy <Manolo>2011-10-04 13:10:55 +0000
committerManolo Gouy <Manolo>2011-10-04 13:10:55 +0000
commit5e136f4c39a5966a171dab58277418ffd0694c82 (patch)
tree3f89a338f660ae85636c027996f1322e7a4f17d1 /FL/Fl_Widget.H
parentd8a1aea23e721530a241d723bf39727f411338e7 (diff)
Remove Doxygen warnings introduced at r.9116
git-svn-id: file:///fltk/svn/fltk/branches/branch-1.3@9126 ea41ed52-d2ee-0310-a9c1-e6b18d33e121
Diffstat (limited to 'FL/Fl_Widget.H')
-rw-r--r--FL/Fl_Widget.H8
1 files changed, 4 insertions, 4 deletions
diff --git a/FL/Fl_Widget.H b/FL/Fl_Widget.H
index e765c3a9d..7e7ed615a 100644
--- a/FL/Fl_Widget.H
+++ b/FL/Fl_Widget.H
@@ -851,10 +851,10 @@ public:
*/
int contains(const Fl_Widget *w) const ;
- /** Checks if this widget is a child of w.
- Returns 1 if this widget is a child of \p w, or is
- equal to \p w. Returns 0 if \p w is NULL.
- \param[in] w the possible parent widget.
+ /** Checks if this widget is a child of \p wgt.
+ Returns 1 if this widget is a child of \p wgt, or is
+ equal to \p wgt. Returns 0 if \p wgt is NULL.
+ \param[in] wgt the possible parent widget.
\see contains()
*/
int inside(const Fl_Widget* wgt) const {return wgt ? wgt->contains(this) : 0;}